/*
 *   IRC - Internet Relay Chat, src/modules/m_setrfc.c
 *   (C) 2002-2003 Tiburon <tiburon@betasirc.net>
 *   Copyright (C) 2002-2005 The QuakeIRCd Development Team
 *
 *   See file AUTHORS in IRC package for additional names of
 *   the programmers. 
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 1, or (at your option)
 *   any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
#include "config.h"
#include "struct.h"
#include "common.h"
#include "sys.h"
#include "numeric.h"
#include "msg.h"
#include "channel.h"
#include <time.h>
#include <sys/stat.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#ifdef _WIN32
#include <io.h>
#endif
#include <fcntl.h>
#include "h.h"
#include "proto.h"
#ifdef STRIPBADWORDS
#include "badwords.h"
#endif
#ifdef _WIN32
#include "version.h"
#endif

#define MSG_SETRFC 	"SETRFC"
#define TOK_SETRFC 	"SRFC"

DLLFUNC int m_setrfc(aClient *cptr, aClient *sptr, int parc, char *parv[]);
#ifndef DYNAMIC_LINKING
ModuleHeader m_setrfc_Header
#define Mod_Header m_setrfc_Header
#else
ModuleHeader Mod_Header
#endif
  = {
	"setrfc",	/* Name of module */
	"$Id: m_setrfc.c,v 1.3 2005/02/24 04:57:17 tirc Exp $", /* Version */
	"/setrfc", /* Short description of module */
	"3.2-b8-1",
    };

/*
 * The purpose of these ifdefs, are that we can "static" link the ircd if we
 * want to
*/

#ifdef DYNAMIC_LINKING
DLLFUNC int	Mod_Init(ModuleInfo *modinfo)
#else
int    m_setrfc_Init(ModuleInfo *modinfo)
#endif
{
	/*
	 * We call our add_Command crap here
	*/
	add_Command(MSG_SETRFC, TOK_SETRFC, m_setrfc, MAXPARA);
	return MOD_SUCCESS;
	
}
#ifdef DYNAMIC_LINKING
DLLFUNC int	Mod_Load(int module_load)
#else
int    m_setrfc_Load(int module_load)
#endif
{
	return MOD_SUCCESS;
	
}
#ifdef DYNAMIC_LINKING
DLLFUNC int	Mod_Unload(int module_unload)
#else
int	m_setrfc_Unload(int module_unload)
#endif
{
	if (del_Command(MSG_SETRFC, TOK_SETRFC, m_setrfc) < 0)
	{
		sendto_realops("Failed to delete commands when unloading %s",
				Mod_Header.name);
	}
	return MOD_SUCCESS;
	
}

/* 
 * m_setrfc - 12/08/2003 - Tiburon
 * :prefix SETRFC <nick>
 * parv[0] - sender
 * parv[1] - nickname
 *
*/

DLLFUNC int m_setrfc(aClient *cptr, aClient *sptr, int parc, char *parv[])
{
	aClient *acptr;

#ifndef PRESERVE_BANDWIDTH
	if (MyClient(sptr))
	{
		sendto_one(sptr, ":%s NOTICE %s : The /setrfc command is disabled on this server", me.name, sptr->name);
		return 0;
	}
#endif

	if (MyClient(sptr))
		if (!IsAnOper(sptr))
		{
			sendto_one(sptr, err_str(ERR_NOPRIVILEGES), me.name,
			    parv[0]);
			return 0;

		}

	if (parc < 2)
	{
		sendto_one(sptr,
		    ":%s NOTICE %s : /setrfc syntax is /setrfc <nick>",
		    me.name, sptr->name);
		return 0;
	}

	if (strlen(parv[1]) < 1)
	{
		sendto_one(sptr,
		    ":%s NOTICE %s : You are missing the nick to setrfc",
		    me.name, sptr->name);
		return 0;
	}

	if (strlen(parv[1]) > (NICKLEN))
	{
		sendto_one(sptr,
		    ":%s NOTICE %s : setrfc Error: Nickname too long",
		    me.name, sptr->name);
		return 0;
	}

	if ((acptr = find_person(parv[1], NULL)))
	{
			if (IsRFC(acptr))
			{
			ClearRFC(acptr);
			sendto_one(sptr, ":%s NOTICE %s :RFC is now disabled on %s", me.name, sptr->name, acptr->name);
			sendto_snomask(SNO_EYES, "%s disabled RFC on %s", sptr->name, acptr->name);
			}
			else
			{
			SetRFC(acptr);
			sendto_one(sptr, ":%s NOTICE %s :RFC is now enabled on %s", me.name, sptr->name, acptr->name);
                        sendto_snomask(SNO_EYES, "%s enabled RFC on %s", sptr->name, acptr->name);
			}
		sendto_serv_butone_token(cptr, sptr->name,
		    MSG_SETRFC, TOK_SETRFC, "%s", acptr->name);
	}
	else
	{
		sendto_one(sptr, err_str(ERR_NOSUCHNICK), me.name, sptr->name,
		    parv[1]);
		return 0;
	}
	return 0;
}
